@@ -19,18 +19,14 @@ from salesforce.backend.creation import DatabaseCreation
 from salesforce.backend.introspection import DatabaseIntrospection
 from salesforce.backend.validation import DatabaseValidation
 from salesforce.backend.operations import DatabaseOperations
+from salesforce.backend.driver import IntegrityError, DatabaseError
+from salesforce.backend import driver as Database
 
 log = logging.getLogger(__name__)
 
-class DatabaseError(Exception):
-	pass
-
 class SalesforceError(DatabaseError):
 	pass
 
-class IntegrityError(DatabaseError):
-	pass
-
 class DatabaseFeatures(BaseDatabaseFeatures):
 	"""
 	Features this database provides.
@@ -46,24 +42,29 @@ class DatabaseWrapper(BaseDatabaseWrapper):
 	Core class that provides all DB support.
 	"""
 	vendor = 'salesforce'
+	# Operators [contains, startswithm, endswith] are incorrectly
+	# case insensitive like sqlite3.
 	operators = {
 		'exact': '= %s',
 		'iexact': 'LIKE %s',
-		'contains': 'LIKE BINARY %s',
+		'contains': 'LIKE %s',
 		'icontains': 'LIKE %s',
-		'regex': 'REGEXP BINARY %s',
-		'iregex': 'REGEXP %s',
+		#'regex': 'REGEXP %s',  # unsupported
+		#'iregex': 'REGEXP %s',
 		'gt': '> %s',
 		'gte': '>= %s',
 		'lt': '< %s',
 		'lte': '<= %s',
-		'startswith': 'LIKE BINARY %s',
-		'endswith': 'LIKE BINARY %s',
+		'startswith': 'LIKE %s',
+		'endswith': 'LIKE %s',
 		'istartswith': 'LIKE %s',
 		'iendswith': 'LIKE %s',
-		'isnull': '!= %s',
+		# TODO remove 'isnull' because it's incorrect and unused
+		#'isnull': '!= %s',
 	}
 
+	Database = Database
+
 	def __init__(self, settings_dict, alias='default'):
 		super(DatabaseWrapper, self).__init__(settings_dict, alias)
 		
@@ -76,6 +77,24 @@ class DatabaseWrapper(BaseDatabaseWrapper):
 		self.introspection = DatabaseIntrospection(self)
 		self.validation = DatabaseValidation(self)
 	
+	def get_connection_params(self):
+		settings_dict = self.settings_dict
+		params = settings_dict.copy()
+		params.update(settings_dict['OPTIONS'])
+		return params
+
+	def get_new_connection(self, conn_params):
+		# only simulated a connection interface without connecting really
+		return Database.connect(**conn_params)
+
+	def init_connection_state(self):
+		pass  # nothing to init
+
+	def _set_autocommit(self, autocommit):
+		# SF REST API uses autocommit, but until rollback it is not a
+		# serious problem to ignore autocommit off
+		pass
+
 	def validate_settings(self, d):
 		for k in ('ENGINE', 'CONSUMER_KEY', 'CONSUMER_SECRET', 'USER', 'PASSWORD', 'HOST'):
 			if(k not in d):
