@@ -19,8 +19,12 @@ from django.conf import settings
 from django.db import models
 from django.db.models.base import ModelBase
 from django.db.models.sql import compiler
+# Only these two `on_delete` options are currently supported
+from django.db.models import PROTECT, DO_NOTHING
+#from django.db.models import CASCADE, PROTECT, SET_NULL, SET, DO_NOTHING
 
 from salesforce.backend import manager
+from salesforce.fields import *  # modified django.db.models.CharField etc.
 from salesforce import fields
 
 log = logging.getLogger(__name__)
@@ -53,3 +57,4 @@ class SalesforceModel(models.Model):
 	
 	Id = fields.SalesforceAutoField(primary_key=True)
 
+Model = SalesforceModel
