@@ -12,10 +12,10 @@ DATABASES = {
 	},
 	'salesforce': {
 		'ENGINE': 'salesforce.backend',
-		"CONSUMER_KEY" : '3MVG9GiqKapCZBwFshmMJ7ry5oSWhmdsiCNrTorw.cBx3EOvNPfkX6mPksUdHXoH6hI4q0UX8S7uyHaseqHJN',
-		"CONSUMER_SECRET" : '3051006413681161256',
-		'USER': 'admins@freelancersunion.org.pac2',
-		'PASSWORD': 'Vs^o=D9yu3',
+		"CONSUMER_KEY" : '3MVG9FS3IyroMOh4vLOfNRhSkfk0EjzAVdCh0rlGkrAEcJuwqpUwZMu_bGXYsYosog3jAuBQ.fxPcko3_6F3v',
+		"CONSUMER_SECRET" : '7230885957056046598',
+		'USER': 'pchristensen@freelancersunion.org.devops',
+		'PASSWORD': 'X7iZ\;k%1q',
 		'HOST': 'https://test.salesforce.com',
 	},
 }
